package com.sky.service;

import com.sky.dto.OrdersPaymentDTO;
import com.sky.dto.OrdersSubmitDTO;
import com.sky.result.PageResult;
import com.sky.vo.OrderPaymentVO;
import com.sky.vo.OrderSubmitVO;
import com.sky.vo.OrderVO;

public interface OrderService {
    /**
     * 用户下单
     *
     * @param ordersSubmitDTO 用户下单请求数据
     * @return OrderSubmitVO
     */
    OrderSubmitVO submitOrder(OrdersSubmitDTO ordersSubmitDTO);

    /**
     * 订单支付
     *
     * @param ordersPaymentDTO ordersPaymentDTO
     * @return OrderPaymentVO
     */
    OrderPaymentVO payment(OrdersPaymentDTO ordersPaymentDTO) throws Exception;

    /**
     * 支付成功，修改订单状态
     *
     * @param outTradeNo String
     */
    void paySuccess(String outTradeNo);

    /**
     * 客户催单
     *
     * @param id Long
     */
    void reminder(Long id);

    /**
     * 用户端订单分页查询
     *
     * @param pageNum  当前页
     * @param pageSize 每页显示条数
     * @param status   状态
     * @return PageResult
     */
    PageResult pageQuery4User(int pageNum, int pageSize, Integer status);

    /**
     * 查询订单详情
     *
     * @param id 查询订单id
     * @return OrderVO
     */
    OrderVO detail(Long id);

    /**
     * 取消订单
     *
     * @param id 订单id
     */
    void userCancelById(Long id);
}
